@@ -23,7 +23,7 @@ LIP_BUTTON_RELEASE = 4
 
 LIP_KEEP_ALIVE = "?SYSTEM,10"
 
-CONNECT_TIMEOUT = 10
+CONNECT_TIMEOUT = 45  # The bridge can try to do ident which can take up to 30 seconds
 SOCKET_TIMEOUT = 10
 
 LIP_READ_TIMEOUT = 60
